.. only:: html

   .. include:: main.rst

.. toctree::
   :hidden:

   Home<self>

.. toctree::
   :maxdepth: 2

   main
   docker
   reference
   release-notes
   contributing

.. sidebar-links::
   :caption: Links
   :github:
   :pypi: starbridge

   Docker <https://hub.docker.com/r/helmuthva/starbridge/tags>
   SonarQube <https://sonarcloud.io/summary/new_code?id=helmut-hoffer-von-ankershoffen_starbridge>
   Codecov <https://app.codecov.io/gh/helmut-hoffer-von-ankershoffen/starbridge>
   ghcr.io <https://github.com/helmut-hoffer-von-ankershoffen/starbridge/pkgs/container/starbridge>
   License <https://github.com/helmut-hoffer-von-ankershoffen/starbridge/blob/main/LICENSE>

.. only:: html

   Indices and tables
   ==================

   * :ref:`genindex`
   * :ref:`modindex`
   * :ref:`search`
